
# Type: chemical to gene association_object




URI: [biolink:chemical_to_gene_association_object](https://w3id.org/biolink/vocab/chemical_to_gene_association_object)


## Domain and Range

[ChemicalToGeneAssociation](ChemicalToGeneAssociation.md) ->  <sub>REQ</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [ChemicalToGeneAssociation](ChemicalToGeneAssociation.md)
